==> canvasXpress.data_1.27.6.tar.gz: canvasXpress.data/README.md <==
---
title:  "canvasXpress.data R Library"
output: 
    html_document:
        self_contained: no
---

<a href="http://www.canvasxpress.org"><img src="https://canvasxpress.org/images/brand3.png" align="left" hspace="10" vspace="6" width="100"></a>

<!-- Badge Location -->
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/canvasXpress.data?color=9bc2cf)](https://cran.r-project.org/package=canvasXpress.data)
[![Travis-CI Build Status](https://travis-ci.org/cb4ds/canvasXpress.data.svg?branch=master)](https://travis-ci.org/cb4ds/canvasXpress.data)

<!-- End Badges -->

***canvasXpress.data*** is the source of data files used in visual/shiny examples and tests in the canvasXpress R package


***canvasXpress*** was developed as the core visualization component for bioinformatics and systems biology analysis
at Bristol-Myers Squibb. It supports a large number of [visualizations ](http://www.canvasxpress.org/examples.html) 
to display scientific and non-scientific data. ***canvasXpress*** also includes a simple and unobtrusive 
[user interface](http://www.canvasxpress.org/docs/interface.html) to explore complex data sets -- data can
be easily sorted, grouped, transposed, transformed or clustered dynamically.  The canvasXpress R package is available on 
[CRAN](https://CRAN.R-project.org/package=canvasXpress) and [GitHub](https://github.com/neuhausi/canvasXpress). 

---

### Installation

canvasXpress.data is available for installation from 
[CRAN](https://CRAN.R-project.org/package=canvasXpress.data) or you can install the
latest version of ***canvasXpress.data*** from GitHub as follows:

```r
devtools::install_github('neuhausi/canvasXpress.data')
```

==> canvasXpress.data_1.29.0.tar.gz: canvasXpress.data/README.md <==
---
title:  "canvasXpress.data R Library"
output: 
    html_document:
        self_contained: no
---

<a href="http://www.canvasxpress.org"><img src="https://www.canvasxpress.org/assets/images/logo-square.svg" align="left" height="100px" style="margin: 50px 20px 5px 0px"></a>

<!-- Badge Location -->
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/canvasXpress.data?color=9bc2cf)](https://cran.r-project.org/package=canvasXpress.data)
[![Travis-CI Build Status](https://travis-ci.org/cb4ds/canvasXpress.data.svg?branch=master)](https://travis-ci.org/cb4ds/canvasXpress.data)

<!-- End Badges -->

***canvasXpress.data*** is the source of data files used in visual/shiny examples and tests in the canvasXpress R package


***canvasXpress*** was developed as the core visualization component for bioinformatics and systems biology analysis
at Bristol-Myers Squibb. It supports a large number of [visualizations ](http://www.canvasxpress.org/examples.html) 
to display scientific and non-scientific data. ***canvasXpress*** also includes a simple and unobtrusive 
[user interface](http://www.canvasxpress.org/docs/interface.html) to explore complex data sets -- data can
be easily sorted, grouped, transposed, transformed or clustered dynamically.  The canvasXpress R package is available on 
[CRAN](https://CRAN.R-project.org/package=canvasXpress) and [GitHub](https://github.com/neuhausi/canvasXpress). 

---

### Installation

canvasXpress.data is available for installation from 
[CRAN](https://CRAN.R-project.org/package=canvasXpress.data) or you can install the
latest version of ***canvasXpress.data*** from GitHub as follows:

```r
devtools::install_github('neuhausi/canvasXpress.data')
```
